//
//    Stand alone application to create a shared memory partition.
//
//    Syntax:
//       smcreate <name> [-nbuf <nbuf>] [-lbuf <lbuf>]
//
//       <name>    name of the partition to be created
//       <nbuf>    number of buffers 
//       <lbuf>    length of each buffer in bytes.
//
#include <string.h>
#include <stdlib.h>
#include <iostream>
#include "lsmp.hh"

int 
main(int argc, const char ** argv) {
    const char* name = getenv("LIGOSMPART");

    //-------------------------------  Get the command line arguments
    bool argerr = false;
    for (int i=1 ; i<argc ; i++) {
        if ((i == 1) && (*argv[i] != '-') && (*argv[i] != '?')) {
	    name = argv[i];
	} else {
	    std::cerr << argv[0] << ": Invalid argument " << argv[i] 
		      << std::endl;
	    argerr = true;
	}
    }
    if (!name) argerr = true;

    //-------------------------------  Print an error message if appropriate.
    if (argerr) {
        std::cerr << argv[0] << ": Make the shared memory consumer and buffer "
	     << "data structures consistent" << std::endl;
	std::cerr << "Syntax:" << std::endl;
	std::cerr << argv[0] << " <partition-name>" << std::endl;
	exit(1);
    }

    //-------------------------------  Do the dirty work. Make sure the 
    //                                 partition isn't deleted immediately 
    LSMP_ACCESS *part = new LSMP_ACCESS(name);
    if (!(part->valid())) {
        std::cerr << "Unable to attach partition " << name 
		  << ": " << part-> Error() << "." << std::endl;
    }
    part->Repair();
    delete part;
    exit(0);
}
